@@ -33,7 +33,7 @@ class CommandCallback:
     def __init__(
             self,
             command_callback: Callable,
-            accepted_aliases: Union[list[str], str],
+            accepted_aliases: Union[List[str], str],
             *,
             alias_is_regex: bool = False,
             make_default: bool = False,
@@ -178,7 +178,7 @@ def command_handler(api) -> Callback:
                     await command_callback(api, room, event)
                     return True
             else:
-                if msg.startswith(message):
+                if msg.startswith(message + " ") or msg == message:
                     logger.info(f"Found command in msg: {msg}")
                     await command_callback(api, room, event)
                     return True
@@ -202,7 +202,7 @@ def command_handler(api) -> Callback:
         default_command = [x for x in api.command_callbacks if x.make_default]
         if not found and len(default_command) > 0:
             logger.info(f"Found no command in msg, executing default command")
-            await default_command[0][0](api, room, event)
+            await default_command[0].command_callback(api, room, event)
 
     return callback
 
